{% extends "todo/base.html" %}
{% block page_heading %}{% endblock %}
{% block title %}File Ticket{% endblock %}

{% block content %}

  <h2>{{ task }}</h2>

  <form action="" method="POST">
    {% csrf_token %}

    <h3>File Trouble Ticket</h3>
    <p>
      Have a support issue? Use this form to report the difficulty - we'll get right back to you.
    </p>

    {% if form.errors %}
      {% for error in form.errors %}
        <ul class="errorlist">
          <li>
            <strong>The {{ error|escape }} field is required.</strong>
          </li>
        </ul>
      {% endfor %}
    {% endif %}

    <form action="" name="add_task" method="post">
        {% csrf_token %}
        <div class="form-group">
          <label for="id_title" name="title">Subject</label>
          <input type="text" class="form-control" id="id_title" name="title" required placeholder="Our spaceship doesn't go"
            value="{% if form.title.value %}{{ form.title.value }}{% endif %}">
        </div>
        <div class="form-group">
          <label for="id_note">Description</label>
          <textarea class="form-control" id="id_note" name="note" rows="5"
            aria-describedby="inputNoteHelp">{% if form.note.value %}{{ form.note.value }}{% endif %}</textarea>
          <small id="inputNoteHelp" class="form-text text-muted">
            Describe the issue. Please include essential details.
          </small>
        </div>

        <input type="hidden" id="id_priority" name="priority" value="50">
        <p><input type="submit" class="btn btn-primary" name="add_task" value="Submit"></p>
    </form>

{% endblock %}
