"""
A multi-user, multi-group task management and assignment system for Django.
"""
__version__ = '2.2.0'

__author__ = 'Scot Hacker'
__email__ = 'shacker@birdhouse.org'

__url__ = 'https://github.com/shacker/django-todo'
__license__ = 'BSD License'
