# Generated by Django 2.0.2 on 2018-02-09 23:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0009_alter_user_last_name_max_length'),
        ('todo', '0003_assignee_optional'),
    ]

    operations = [
        migrations.CreateModel(
            name='TaskList',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=60)),
                ('slug', models.SlugField(default='')),
                ('group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='auth.Group')),
            ],
            options={
                'verbose_name_plural': 'Lists',
                'ordering': ['name'],
            },
        ),
        migrations.AlterUniqueTogether(
            name='list',
            unique_together=set(),
        ),
        migrations.RemoveField(
            model_name='list',
            name='group',
        ),
        migrations.RemoveField(
            model_name='item',
            name='list',
        ),
        migrations.DeleteModel(
            name='List',
        ),
        migrations.AddField(
            model_name='item',
            name='task_list',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='todo.TaskList'),
        ),
        migrations.AlterUniqueTogether(
            name='tasklist',
            unique_together={('group', 'slug')},
        ),
    ]
